# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['elastica_pipelines', 'elastica_pipelines.io']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.1',
 'h5py>=3.7.0,<4.0.0',
 'numpy>=1.20.0',
 'typing-extensions>=4.3.0']

entry_points = \
{'console_scripts': ['elastica-pipelines = elastica_pipelines.__main__:main']}

setup_kwargs = {
    'name': 'elastica-pipelines',
    'version': '0.1.0',
    'description': 'Elastica Pipelines',
    'long_description': '# Elastica Pipelines\n\n[![PyPI](https://img.shields.io/pypi/v/elastica-pipelines.svg)][pypi_]\n[![Status](https://img.shields.io/pypi/status/elastica-pipelines.svg)][status]\n[![Python Version](https://img.shields.io/pypi/pyversions/elastica-pipelines)][python version]\n[![License](https://img.shields.io/pypi/l/elastica-pipelines)][license]\n\n[![Read the documentation at https://elastica-pipelines.readthedocs.io/](https://img.shields.io/readthedocs/elastica-pipelines/latest.svg?label=Read%20the%20Docs)][read the docs]\n[![Tests](https://github.com/tp5uiuc/elastica-pipelines/workflows/Tests/badge.svg)][tests]\n[![Codecov](https://codecov.io/gh/tp5uiuc/elastica-pipelines/branch/main/graph/badge.svg)][codecov]\n\n[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)][pre-commit]\n[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)][black]\n\n[pypi_]: https://pypi.org/project/elastica-pipelines/\n[status]: https://pypi.org/project/elastica-pipelines/\n[python version]: https://pypi.org/project/elastica-pipelines\n[read the docs]: https://elastica-pipelines.readthedocs.io/\n[tests]: https://github.com/tp5uiuc/elastica-pipelines/actions?workflow=Tests\n[codecov]: https://app.codecov.io/gh/tp5uiuc/elastica-pipelines\n[pre-commit]: https://github.com/pre-commit/pre-commit\n[black]: https://github.com/psf/black\n\n## Features\n\n### IO\n\n- Lazy loading of simulation time-series data generated by **Elastica++** applications\n- Track a single, or a subset, or whole group of rods, over time using familiar slicing API\n\n## Installation\n\nYou can install _Elastica Pipelines_ via [pip] from [PyPI]:\n\n```console\n$ pip install elastica-pipelines\n```\n\n## Usage\n\nPlease see the [Command-line Reference] for details.\n\n### IO\n\n[![Python3][api-py3]](https://www.python.org/) ![Python3 API: Alpha][dev-alpha]\n\n[api-py3]: https://img.shields.io/badge/language-Python3-yellowgreen "Python3 API"\n[dev-alpha]: https://img.shields.io/badge/phase-alpha-yellowgreen "Status: Alpha"\n\n```py\nfrom elastica_pipelines import io\n\n# ...\n\n# Read only access to data written by Elastica++\nseries = io.series(metadata="elastica_metadata.h5")\n\n# use series like a python Mapping\nfor t, snapshot in series.iterations():\n    print("Iteration: {0} at time {1}".format(t.iterate, t.time))\n\n    # Snapshot is a mapping contain system types such as CosseratRods & Spheres\n    # Here we access only cosserat rods\n    for rod_id, rod in snapshot.cosserat_rods().items(): # snapshot[\'CosseratRod\'] also works!\n        if rod_id == 0:\n            print("  Rod \'{0}\' attributes:".format(rod_id))\n            # even rod is a Mapping, get its keys\n            print("  {0}".format(list(rod.keys())))\n        print("  Rod \'{0}\' position:".format(rod_id), rod[\'Position\'])\n```\n\n## Contributing\n\nContributions are very welcome.\nTo learn more, see the [Contributor Guide].\n\n## License\n\nDistributed under the terms of the [MIT license][license],\n_Elastica Pipelines_ is free and open source software.\n\n## Issues\n\nIf you encounter any problems,\nplease [file an issue] along with a detailed description.\n\n## Credits\n\nThis project was generated from [@cjolowicz]\'s [Hypermodern Python Cookiecutter] template.\n\n[@cjolowicz]: https://github.com/cjolowicz\n[pypi]: https://pypi.org/\n[hypermodern python cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python\n[file an issue]: https://github.com/tp5uiuc/elastica-pipelines/issues\n[pip]: https://pip.pypa.io/\n\n<!-- github-only -->\n\n[license]: https://github.com/tp5uiuc/elastica-pipelines/blob/main/LICENSE\n[contributor guide]: https://github.com/tp5uiuc/elastica-pipelines/blob/main/CONTRIBUTING.md\n[command-line reference]: https://elastica-pipelines.readthedocs.io/en/latest/usage.html\n',
    'author': 'ElasticaDev',
    'author_email': 'tp5@illinois.edu',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/tp5uiuc/elastica-pipelines',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
